==> react-source-render-3.0.0-0.tgz: package/dist-src/SourceRender.js <==
import _extends from "@babel/runtime-corejs2/helpers/extends";
import _objectWithoutProperties from "@babel/runtime-corejs2/helpers/objectWithoutProperties";
import _classCallCheck from "@babel/runtime-corejs2/helpers/classCallCheck";
import _createClass from "@babel/runtime-corejs2/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime-corejs2/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime-corejs2/helpers/getPrototypeOf";
import _inherits from "@babel/runtime-corejs2/helpers/inherits";
import _assertThisInitialized from "@babel/runtime-corejs2/helpers/assertThisInitialized";
import _defineProperty from "@babel/runtime-corejs2/helpers/defineProperty";
import * as PropTypes from "prop-types";
import * as React from "react";
import { ComponentRender } from "./ComponentRender.js";
export var SourceRender =
/*#__PURE__*/
function (_React$Component) {
  _inherits(SourceRender, _React$Component);

  function SourceRender() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, SourceRender);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(SourceRender)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      error: null,
      source: ''
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "fallbackElement", React.createRef());

    return _this;
  }

  _createClass(SourceRender, [{
    key: "render",
    value: function render() {
      var _ref = this.props,
          wrap = _ref.wrap,
          rest = _objectWithoutProperties(_ref, ["wrap"]);

      var error = this.state.error;
      return wrap(React.createElement(ComponentRender, _extends({}, rest, {
        fallbackElement: this.fallbackElement,
        runtimeError: error
      })));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(props, state) {
      return {
        source: props.source,
        error: props.source === state.source ? state.error : null
      };
    }
  }, {
    key: "getDerivedStateFromError",
    value: function getDerivedStateFromError(error) {
      return {
        error: error
      };
    }
  }]);

  return SourceRender;
}(React.Component);

_defineProperty(SourceRender, "propTypes", {
  babelConfig: PropTypes.object,
  children: PropTypes.func.isRequired,
  renderHtml: PropTypes.bool,
  resolver: PropTypes.func.isRequired,
  resolverContext: PropTypes.object,
  source: PropTypes.string.isRequired,
  wrap: PropTypes.func
});

_defineProperty(SourceRender, "defaultProps", {
  babelConfig: {},
  renderHtml: true,
  resolverContext: {},
  wrap: function wrap(children) {
    return children;
  }
});

==> react-source-render-3.0.0-5.tgz: package/dist-src/SourceRender.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import * as PropTypes from "prop-types";
import * as React from "react";
import { ComponentRender } from "./ComponentRender.js";
export var SourceRender =
/*#__PURE__*/
function (_React$Component) {
  _inherits(SourceRender, _React$Component);

  function SourceRender() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, SourceRender);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(SourceRender)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      error: null,
      source: ''
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "fallbackElement", React.createRef());

    return _this;
  }

  _createClass(SourceRender, [{
    key: "render",
    value: function render() {
      var _ref = this.props,
          wrap = _ref.wrap,
          rest = _objectWithoutProperties(_ref, ["wrap"]);

      var error = this.state.error;
      return wrap(React.createElement(ComponentRender, _extends({}, rest, {
        fallbackElement: this.fallbackElement,
        runtimeError: error,
        wrap: wrap
      })));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(props, state) {
      return {
        source: props.source,
        error: props.source === state.source ? state.error : null
      };
    }
  }, {
    key: "getDerivedStateFromError",
    value: function getDerivedStateFromError(error) {
      return {
        error: error
      };
    }
  }]);

  return SourceRender;
}(React.Component);

_defineProperty(SourceRender, "propTypes", {
  babelConfig: PropTypes.object,
  children: PropTypes.func.isRequired,
  renderHtml: PropTypes.bool,
  resolver: PropTypes.func.isRequired,
  resolverContext: PropTypes.object,
  source: PropTypes.string.isRequired,
  unstable_hot: PropTypes.bool,
  wrap: PropTypes.func
});

_defineProperty(SourceRender, "defaultProps", {
  babelConfig: {},
  renderHtml: true,
  resolverContext: {},
  unstable_hot: false,
  wrap: function wrap(children) {
    return children;
  }
});
